// Make CBP tables and charts


foreach g in window ps eps svg {
	foreach f in fontface fontfaceserif fontfacemono fontfacesymbol fontfacesans {
		graph set `g' `f' times
	}
}



*******************************************
* Table: summary stats
use "../data/intermediate data/cbp_panel",clear
*duplicates drop fips year,force


// To ensure we put zeros where they should be, we need master list of fips
// That is, if a county has no ogmin activity, it wont appear in cpb_panel in ogmin lines. We need it to appear as zero.
preserve
	keep fips region_id control year ctyemp ctyest
	duplicates drop fips year, force
	sort fips year
	tempfile fips
	save `fips',replace
restore
	
	
preserve
	keep if inlist(substr(naics,1,3),"211","213")
	bys year fips: egen ogemp=sum(emp)
	bys year fips: egen ogest=sum(est)
	duplicates drop year fips, force
	keep year fips ogemp ogest ctyemp ctyest
	
	sort fips
	merge 1:1 fips year using `fips'
	* Should be no _merge==1. If _merge==2 then county has no ogmin emp or est
	drop _merge
	
	replace ogemp=0 if ogemp==.
	replace ogest=0 if ogest==.
	
	
	gen ogmin_empsharet=100*ogemp/ctyemp
	gen ogmin_estsharet=100*ogest/ctyest
	
	drop if year<2000 | year>2006
	
	
	bys fips: egen ogmin_empshare=mean(ogmin_empsharet)
	bys fips: egen ogmin_estshare=mean(ogmin_estsharet)
	drop ogmin_empsharet ogmin_estsharet
	
	keep fips region_id control ogmin*
	duplicates drop fips,force
	
	
	*Shale
	gen emp30=ogmin_empshare if region_id!=0 //will convert 30 to -3, shale
	gen est30=ogmin_estshare if region_id!=0
	
	forvalues i=0/7 {
		gen emp`i'=ogmin_empshare if region_id==`i'
		gen est`i'=ogmin_estshare if region_id==`i'
	}
	rename emp0 emp10 //will convert 10 to -1, nonshale
	rename est0 est10
	
	gen emp20=ogmin_empshare if inlist(region_id,1,3,4,7) //boom towns
	gen est20=ogmin_estshare if inlist(region_id,1,3,4,7)
	
	gen emp0=ogmin_empshare if control==1 //control set
	gen est0=ogmin_estshare if control==1
	
	
	collapse (mean) emp30-est0
	gen dumbindex=1
	
	reshape long emp est,i(dumbindex) j(region_id)
	
	replace region_id=-region_id/10 if region_id>9
	
	rename emp ogempshare
	rename est ogestshare
	drop dumbindex
	sort region_id
	
	tempfile ogstuff
	save `ogstuff',replace
restore

	
keep if year>1999 & year<2007
	
	
	


// Shale overall first
preserve
	keep if region!=0 //Shale
	replace region=-3
	
	* Define our supersectors, not exactly same as BLS
	drop if substr(naics,4,1)=="/"
	gen naicst=substr(naics,1,2)
	destring naicst,gen(naics2)

	keep year fips region emp est naics2 
	replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
	replace naics2=60 if inlist(naics2,54,55,56) //PBS
	replace naics2=65 if inlist(naics2,61,62) //Ed & health
	replace naics2=70 if inlist(naics2,71,72) //L&H
	
	collapse (sum) emp est,by(year fips naics2)
	collapse (mean) emp est,by(fips naics2) // Want 2000-2006 average
	
	reshape wide emp est,i(fips) j(naics2)
	
	foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
		replace emp`i'=0 if emp`i'==.
		replace est`i'=0 if est`i'==.
	}
	
	*drop emp* //Could keep if change mind
	sort fips
	tempfile shalesectors
	save `shalesectors',replace
restore
preserve
	keep if region!=0 //Shale
	replace region=-3
	
	duplicates drop fips year,force
	collapse (mean) ctyemp ctyest,by(fips)
	
	sort fips
	merge 1:1 fips using `shalesectors'
	
	gen region_id=-3
	collapse (mean) ctyemp ctyest emp21-est90,by(region)
	
	
	
	tempfile shale
	save `shale',replace
restore


// Now by play, including nonshale
preserve
	* Define our supersectors, not exactly same as BLS
	drop if substr(naics,4,1)=="/"
	gen naicst=substr(naics,1,2)
	destring naicst,gen(naics2)

	keep year fips emp est naics2 
	replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
	replace naics2=60 if inlist(naics2,54,55,56) //PBS
	replace naics2=65 if inlist(naics2,61,62) //Ed & health
	replace naics2=70 if inlist(naics2,71,72) //L&H
	
	collapse (sum) emp est,by(year fips naics2)
	collapse (mean) emp est,by(fips naics2) //Want 2000-2006 average
	
	reshape wide emp est,i(fips) j(naics2)
	
	foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
		replace emp`i'=0 if emp`i'==.
		replace est`i'=0 if est`i'==.
	}
	
	*drop emp* //Could keep if change mind
	sort fips
	tempfile nonshalesectors
	save `nonshalesectors',replace
restore

preserve
	duplicates drop fips year,force
	collapse (mean) ctyemp ctyest,by(region fips)

	sort fips
	merge 1:1 fips using `nonshalesectors'
	
	collapse (mean) ctyemp ctyest emp21-est90,by(region)
	
	replace region=-1 if region==0 //Non-shale
	tempfile byplay
	save `byplay',replace
restore


// Boom towns and control set
keep if inlist(region_id,1,3,4,7) | control==1
replace region_id=-2 if inlist(region_id,1,3,4,7)
replace region_id=0 if control==1

preserve
	* Define our supersectors, not exactly same as BLS
	drop if substr(naics,4,1)=="/"
	gen naicst=substr(naics,1,2)
	destring naicst,gen(naics2)

	keep year fips emp est naics2 
	replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
	replace naics2=60 if inlist(naics2,54,55,56) //PBS
	replace naics2=65 if inlist(naics2,61,62) //Ed & health
	replace naics2=70 if inlist(naics2,71,72) //L&H
	
	collapse (sum) emp est,by(year fips naics2)
	collapse (mean) emp est,by(fips naics2) //Want 2000-2006 average
	
	reshape wide emp est,i(fips) j(naics2)
	
	foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
		replace emp`i'=0 if emp`i'==.
		replace est`i'=0 if est`i'==.
	}
	
	*drop emp* //Could keep if change mind
	sort fips
	tempfile boomsectors
	save `boomsectors',replace
restore


duplicates drop fips year,force
collapse (mean) ctyemp ctyest,by(region fips)
sort fips

merge 1:1 fips using `boomsectors'


label define regionidlabel2 ///
-3 "Shale counties" ///
-2 "Boom towns" ///
-1 "Non-shale counties" ///
0 "Non-shale control set"		/// 
1 "Anadarko" ///
2 "Appalachia" ///
3 "Bakken" ///
4 "Eagle Ford" /// 
5 "Haynesville" /// 
6 "Niobrara" /// 
7 "Permian Basin" ///
8 "Boom towns"
label values region_id regionidlabel2

collapse (mean) ctyemp ctyest emp21-est90,by(region)
tempfile byboom
save `byboom',replace


append using `byplay'
append using `shale'
sort region

merge 1:1 region using `ogstuff'
replace ogempshare=round(ogempshare,.1)
replace ogestshare=round(ogestshare,.1)

gen str_ogempshare=string(ogempshare,"%2.1f")
gen str_ogestshare=string(ogestshare,"%2.1f")
drop ogempshare ogestshare

rename str_ogempshare ogempshare
rename str_ogestshare ogestshare

drop _merge

replace ctyemp=round(ctyemp,100)
replace ctyest=round(ctyest,10)

foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
	replace est`i'=round(est`i',1)
	replace emp`i'=round(emp`i',10)
}

decode region_id,gen(region)
drop region_id
order region

tostring ctyemp-est90,replace force

*** Do 2 tables. Table 1 is totals and some industry emp shares.
* Table 2 is est counts by supersector

*Table 1
capture file close table1
file open table1 using "../output/table1.tex",write text replace
file write table1 "\footnotesize" _n
file write table1 "\begin{tabular}{lcc|cc}" _n 
file write table1 "\hline \\" _n 

file write table1 " &     Total      &     Total      &   Oil \& gas mining   &   Oil \& gas mining   \\" _n
file write table1 " &   employment   & establishments & share of employment  &   share of estabs    \\" _n
file write table1 " & & & (\%) & (\%) \\" _n
file write table1 "\hline" _n
file write table1 " & & & & \\" _n

*Finish table 1 below after prepping table 2

*Table 2:


capture file close table2	
file open table2 using "../output/table2.tex", write text replace

file write table2 "\footnotesize" _n
file write table2 "\begin{tabular}{lccccccccccc}" _n 

file write table2 "\hline \\" _n 

**This is where you put the column labels in. I have them set up as two rows each. You can also do one row and just fill in
**the top or bottom ones. 
file write table2 " &  Min  &  Uti  &  Con  &  Man  &  Ret  &  Tran &  Prof & Educ  &  Leis &  Oth  \\" _n
file write table2 " &       &       &       &       &       &\& ware & \& biz &\& heal &\& hosp & svcs  \\" _n

file write table2 "\hline \\" _n


* Appendix version of Table 2 with employment instead of ests
capture file close tableA1	
file open tableA1 using "../output/tableA1.tex", write text replace

file write tableA1 "\footnotesize" _n
file write tableA1 "\begin{tabular}{lccccccccccc}" _n 

file write tableA1 "\hline \\" _n 

**This is where you put the column labels in. I have them set up as two rows each. You can also do one row and just fill in
**the top or bottom ones. 
file write tableA1 " &  Min  &  Uti  &  Con  &  Man  &  Ret  &  Tran &  Prof & Educ  &  Leis &  Oth  \\" _n
file write tableA1 " &       &       &       &       &       &\& ware & \& biz &\& heal &\& hosp & svcs  \\" _n

file write tableA1 "\hline \\" _n


capture gen row = _n

*this is where the data is actually written in to the table
*You have to adjust the things to the right of [`r'] below to the variable names you want

gen id = _n

levelsof id, local(vars)
di `vars'
foreach v of local vars  {
  qui sum row if id==`v'
  
	local r=r(mean)
	di "`r'"
	
	local region=region[`r']
	local t1=ctyemp[`r']
	local t2=ctyest[`r']
	local t3=ogempshare[`r']
	local t4=ogestshare[`r']
	
	
	
	
	
	
	global lineout2="`region'"
	global lineoutA1="`region'"
	
	
	foreach j in 21 22 23 31 44 48 60 65 70 81 {
	di "`j'"
		local e=est`j'[`r']
		local m=emp`j'[`r']
		
		global lineout2="$lineout2 & `e'"
		di "$lineout2"
		
		global lineoutA1="$lineoutA1 & `m'"
	}
	
	if "`r'"=="5" {
		file write table2 "\hline \\" _n
		file write tableA1 "\hline \\" _n
		
		file write table1 "\hline" _n
		file write table1 " & & & & \\"
	}
	
	global lineout1="`region' & `t1' & `t2' & `t3' & `t4' \\"
	file write table1 "$lineout1" _n
	
	file write table2 "$lineout2    \\" _n
	
	file write tableA1 "$lineoutA1      \\" _n
	
	
	
	
}
*

*Wrap up table 1
file write table1 "\hline" _n
file write table1 "\multicolumn{5}{l}{Note: Average county-level figures by play and NAICS sector for 2000-2006. Employment and}\\" _n
file write table1 "\multicolumn{5}{l}{establishment counts rounded to nearest 100 and 10, respectively. Oil \& gas mining includes}\\" _n
file write table1 "\multicolumn{5}{l}{NAICS 211 and 213. Boom towns include counties in Anadarko, Bakken, Eagle Ford, and Permian}\\" _n
file write table1 "\multicolumn{5}{l}{Basin. Non-shale counties include all U.S. counties outside shale areas. Non-shale control set}\\" _n
file write table1 "\multicolumn{5}{l}{includes all counties except those in shale states and states adjacent to shale counties (see text).}\\" _n
file write table1 "\multicolumn{5}{l}{Source: County Business Patterns}\\" _n
file write table1 "\end{tabular}" _n
file close table1	


*Wrap up table 2
file write table2 "\hline" _n
file write table2 "\multicolumn{11}{l}{Note: Average county-level establishment counts by play and NAICS sector for 2000-2006. Sectors}\\" _n
file write table2 "\multicolumn{11}{l}{are mining; utilities; construction; manufacturing; retail trade; transportation and warehousing;}\\" _n
file write table2 "\multicolumn{11}{l}{professional and business services; education and health; leisure and hospitality; and other services.}\\" _n
file write table2 "\multicolumn{11}{l}{Residual sectors omitted. Boom towns include counties in Anadarko, Bakken, Eagle Ford, and}\\" _n
file write table2 "\multicolumn{11}{l}{Permian Basin. Non-shale counties include all U.S. counties outside shale areas. Non-shale control}\\" _n
file write table2 "\multicolumn{11}{l}{set includes all counties except those in shale states and states adjacent to shale counties (see text).}\\" _n
file write table2 "\multicolumn{11}{l}{Source: County Business Patterns}\\" _n
file write table2 "\end{tabular}" _n
file close table2		


*Wrap up table A1
file write tableA1 "\hline" _n
file write tableA1 "\multicolumn{11}{l}{Note: Average county-level employment by play and NAICS sector for 2000-2006. Sectors are mining;}\\" _n
file write tableA1 "\multicolumn{11}{l}{utilities; construction; manufacturing; retail trade; transportation and warehousing; professional and}\\" _n
file write tableA1 "\multicolumn{11}{l}{business services; education and health; leisure and hospitality; and other services. Residual sectors}\\" _n
file write tableA1 "\multicolumn{11}{l}{omitted. Boom towns include counties in Anadarko, Bakken, Eagle Ford, and Permian Basin. Non-shale}\\" _n
file write tableA1 "\multicolumn{11}{l}{counties include all U.S. counties outside shale areas. Non-shale control set includes all counties except}\\" _n
file write tableA1 "\multicolumn{11}{l}{those in shale states and states adjacent to shale counties (see text).}\\" _n
file write tableA1 "\multicolumn{11}{l}{Source: County Business Patterns}\\" _n
file write tableA1 "\end{tabular}" _n
file close tableA1	










*******************************************
* Chart: emp and est counts, nonogmin. Posgroup
use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) | control==1 // Limit to control group choice set, and posgroup (Ana, Bak,EF,Perm)

gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

bys year fips: egen emp_ogmin=sum(emp_ogmint)
bys year fips: egen est_ogmin=sum(est_ogmint)

replace emp_ogmin=0 if emp_ogmin==.
replace est_ogmin=0 if est_ogmin==.

duplicates drop year fips, force

replace ctyemp=ctyemp-emp_ogmin
replace ctyest=ctyest-est_ogmin

keep year fips shale ctyemp ctyest

collapse (mean) ctyemp ctyest,by(year shale)
rename ctyemp emp
rename ctyest est

gen emp2006_t=emp if year==2006
gen est2006_t=est if year==2006

bys shale: egen emp2006=mean(emp2006_t)
bys shale: egen est2006=mean(est2006_t)

replace emp=100*emp/emp2006
replace est=100*est/est2006

keep year shale emp est

reshape wide emp est,i(year) j(shale)

preserve
	use "../data/intermediate data/cbp_panel",clear
	keep if region_id!=0
	
	gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
	gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

	bys year fips: egen emp_ogmin=sum(emp_ogmint)
	bys year fips: egen est_ogmin=sum(est_ogmint)

	duplicates drop year fips, force

	replace ctyemp=ctyemp-emp_ogmin
	replace ctyest=ctyest-est_ogmin


	keep year fips ctyemp ctyest
	
	collapse (mean) ctyemp ctyest,by(year)
	rename ctyemp empshale
	rename ctyest estshale
	
	gen emp2006_t=empshale if year==2006
	gen est2006_t=estshale if year==2006
	
	egen emp2006=mean(emp2006_t)
	egen est2006=mean(est2006_t)
	
	replace empshale=100*empshale/emp2006
	replace estshale=100*estshale/est2006
	
	keep year empshale estshale
	
	tempfile shale
	save `shale',replace
restore

sort year
merge 1:1 year using `shale'


graph twoway /*
*/(connected empshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected emp1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected emp0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
*/legend(label(1 "Shale counties") label(2 "Boom towns") label(3 "Non-shale control superset") region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(6) keygap(1) rowgap(1))/*
*/subtitle("Employment",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save empcount,replace
label variable empshale "Shale counties"
label variable emp1 "Boom towns"
label variable emp0 "Non-shale control set"
export excel year empshale emp1 emp0 using ../../chartpack.xlsx,sheet("fig2a") firstrow(varlabels) sheetreplace

graph twoway /*
*/(connected estshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected est1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected est0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
legend(label(1 "Shale counties") label(2 "Non-shale counties") region(lcolor(white)) position(11) ring(0) cols(1) size(medlarge) symxsize(4) keygap(1) rowgap(1))
*/legend(off)/*
*/subtitle("Establishments",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save estcount,replace
label variable estshale "Shale counties"
label variable est1 "Boom towns"
label variable est0 "Non-shale control set"
export excel year estshale est1 est0 using ../../chartpack.xlsx,sheet("fig2b") firstrow(varlabels) sheetreplace


graph combine empcount.gph estcount.gph, iscale(1)/*
subtitle("Economic activity excluding oil & gas mining, shale vs. non-shale counties",justification(left) margin(b+1 t) bexpand size(large)) 
*/graphregion(color(white) margin(tiny))/*
*/note("Note: Average county-level employment and establishment counts scaled by 2006 averages."/*
*/"Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. Excludes NAICS 211 and 213. States that include or border shale counties omitted.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/cbp_posgroup_allcounts.pdf,replace



*******************************************
* Chart: emp and est counts, ogmin. Posgroup
use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) | control==1 // Limit to control group choice set, and posgroup (Ana, Bak,EF,Perm)

gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

bys year fips: egen emp_ogmin=sum(emp_ogmint)
bys year fips: egen est_ogmin=sum(est_ogmint)

replace emp_ogmin=0 if emp_ogmin==.
replace est_ogmin=0 if est_ogmin==.

keep year fips shale emp_ogmin est_ogmin
duplicates drop year fips,force


collapse (mean) emp_ogmin est_ogmin,by(year shale)
rename emp_ogmin emp
rename est_ogmin est

gen emp2006_t=emp if year==2006
gen est2006_t=est if year==2006

bys shale: egen emp2006=mean(emp2006_t)
bys shale: egen est2006=mean(est2006_t)

replace emp=100*emp/emp2006
replace est=100*est/est2006

keep year shale emp est

reshape wide emp est,i(year) j(shale)

preserve
	use "../data/intermediate data/cbp_panel",clear
	keep if region_id!=0
	
	gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
	gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

	bys year fips: egen emp_ogmin=sum(emp_ogmint)
	bys year fips: egen est_ogmin=sum(est_ogmint)
	keep year fips shale emp_ogmin est_ogmin
	duplicates drop year fips,force


	collapse (mean) emp_ogmin est_ogmin,by(year shale)
	rename emp_ogmin empshale
	rename est_ogmin estshale
	
	gen emp2006_t=empshale if year==2006
	gen est2006_t=estshale if year==2006
	
	egen emp2006=mean(emp2006_t)
	egen est2006=mean(est2006_t)
	
	replace empshale=100*empshale/emp2006
	replace estshale=100*estshale/est2006
	
	keep year empshale estshale
	
	tempfile shale
	save `shale',replace
restore

sort year
merge 1:1 year using `shale'


graph twoway /*
*/(connected empshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected emp1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected emp0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
*/legend(label(1 "Shale counties") label(2 "Boom towns") label(3 "Non-shale control set") region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(6) keygap(1) rowgap(1))/*
*/subtitle("Employment",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save empcount,replace
label variable empshale "Shale counties"
label variable emp1 "Boom towns"
label variable emp0 "Non-shale control set"
export excel year empshale emp1 emp0 using ../../chartpack.xlsx,sheet("fig1a") firstrow(varlabels) sheetreplace


graph twoway /*
*/(connected estshale year,lwidth(thick) lpattern(longdash) lcolor(orange) msymbol(i))/*
*/(connected est1 year,lwidth(thick) lpattern(dash) lcolor(blue) msymbol(i))/*
*/(connected est0 year,lwidth(thick) lcolor(black) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2000(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Percent of 2006 level",size(4.5))/*
legend(label(1 "Shale counties") label(2 "Non-shale counties") region(lcolor(white)) position(11) ring(0) cols(1) size(medlarge) symxsize(4) keygap(1) rowgap(1))
*/legend(off)/*
*/subtitle("Establishments",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save estcount,replace
label variable estshale "Shale counties"
label variable est1 "Boom towns"
label variable est0 "Non-shale control set"
export excel year estshale est1 est0 using ../../chartpack.xlsx,sheet("fig1b") firstrow(varlabels) sheetreplace


graph combine empcount.gph estcount.gph, iscale(1)/*
subtitle("Oil and gas mining activity, shale vs. non-shale counties",justification(left) margin(b+1 t) bexpand size(large))
*/ graphregion(color(white) margin(tiny))/*
*/note("Note: Average county-level employment and establishment counts scaled by 2006 averages."/*
*/"Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. NAICS 211 and 213. States that include or border shale counties omitted.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/cbp_posgroup_ogcounts.pdf,replace














*******************************************
* Chart: emp counts, each play, ogmin vs nonogmin
use "../data/intermediate data/cbp_panel",clear
keep if shale==1 // 

gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

bys year fips: egen emp_ogmin=sum(emp_ogmint)
bys year fips: egen est_ogmin=sum(est_ogmint)

replace emp_ogmin=0 if emp_ogmin==.
replace est_ogmin=0 if est_ogmin==.

duplicates drop year fips, force

gen emp_nonogmin=ctyemp-emp_ogmin

collapse (sum) emp_ogmin emp_nonogmin,by(year region_id)

preserve
	collapse (sum) emp_ogmin emp_nonogmin,by(year)
	gen region_id=8
	tempfile allplays
	save `allplays',replace
restore

append using `allplays'

preserve
	keep if inlist(region_id,1,3,4,7)
	collapse (sum) emp_ogmin emp_nonogmin,by(year)
	gen region_id=9
	tempfile posgroup
	save `posgroup',replace
restore

append using `posgroup'

label define regionidlabel2 ///
0 "Non-Shale"		/// 
1 "Anadarko" ///
2 "Appalachia" ///
3 "Bakken" ///
4 "Eagle Ford" /// 
5 "Haynesville" /// 
6 "Niobrara" /// 
7 "Permian" ///
8 "All plays" ///
9 "Boom towns"

label values region_id regionidlabel2

drop if year<2006
gen emp_ogmin2000t=emp_ogmin if year==2006
gen emp_nonogmin2000t=emp_nonogmin if year==2006

bys region_id: egen emp_ogmin2000=mean(emp_ogmin2000t)
bys region_id: egen emp_nonogmin2000=mean(emp_nonogmin2000t)

replace emp_ogmin=100*(emp_ogmin/emp_ogmin2000-1)
replace emp_nonogmin=100*(emp_nonogmin/emp_nonogmin2000-1)

keep year region_id emp_ogmin emp_nonogmin
rename emp_ogmin o
rename emp_nonogmin n

reshape wide o n,i(year) j(region_id)

graph twoway /*
*/(connected o1 year,lwidth(thick) lpattern(longdash) msymbol(i)) (connected o2 year,lwidth(thick) lpattern(dash) msymbol(i)) /*
*/(connected o3 year,lwidth(thick) lpattern(shortdash) msymbol(i)) (connected o4 year,lwidth(thick) lpattern(longdash) msymbol(D)) /*
*/(connected o5 year,lwidth(thick) lpattern(dash) msymbol(S)) (connected o6 year,lwidth(thick) lpattern(shortdash) msymbol(O)) /*
*/(connected o7 year,lwidth(thick) lpattern(longdash) msymbol(T)) (connected o8 year,lwidth(vthick) msymbol(i)) /*
*/(connected o9 year,lwidth(vthick) msymbol(D)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2006(4)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Relative to 2006 value (%)",size(4.5))/*
*/legend(label(1 "Anadarko") label(2 "Appalachia") label(3 "Bakken") label(4 "Eagle Ford") label(5 "Haynesville") label(6 "Niobrara") label(7 "Permian Basin") label(8 "All plays") label(9 "Boom towns") /*
*/ region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(9) keygap(1) rowgap(1))/*
*/subtitle("Oil & gas mining",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save ogmin,replace

label variable o1 "Anadarko"
label variable o2 "Appalachia"
label variable o3 "Bakken"
label variable o4 "Eagle Ford"
label variable o5 "Haynesville"
label variable o6 "Niobrara"
label variable o7 "Permian Basin"
label variable o8 "All plays"
label variable o9 "Boom towns"




graph twoway /*
*/(connected n1 year,lwidth(thick) lpattern(longdash) msymbol(i)) (connected n2 year,lwidth(thick) lpattern(dash) msymbol(i)) /*
*/(connected n3 year,lwidth(thick) lpattern(shortdash) msymbol(i)) (connected n4 year,lwidth(thick) lpattern(longdash) msymbol(D)) /*
*/(connected n5 year,lwidth(thick) lpattern(dash) msymbol(S)) (connected n6 year,lwidth(thick) lpattern(shortdash) msymbol(O)) /*
*/(connected n7 year,lwidth(thick) lpattern(longdash) msymbol(T)) (connected n8 year,lwidth(vthick) msymbol(i)) /*
*/(connected n9 year,lwidth(vthick) msymbol(D)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/xtitle("") xlabel(2006(4)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Relative to 2006 value (%)",size(4.5))/*
*/legend(off)/*
*/subtitle("Excluding oil & gas mining",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save nonogmin,replace

label variable n1 "Anadarko"
label variable n2 "Appalachia"
label variable n3 "Bakken"
label variable n4 "Eagle Ford"
label variable n5 "Haynesville"
label variable n6 "Niobrara"
label variable n7 "Permian Basin"
label variable n8 "All plays"
label variable n9 "Boom towns"




graph combine ogmin.gph nonogmin.gph, iscale(1)/*
subtitle("Employment gains by shale play",justification(left) margin(b+1 t) bexpand size(large))
*/ graphregion(color(white) margin(tiny))/*
*/note("Note: Play-level employment relative to 2006. Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. Oil & gas mining is NAICS 211 and 213.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/cbp_emp_byplay.pdf,replace



		





*******************************************
* Chart: accounting for emp gains with change in est counts: ogmin vs nonogmin
use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) //posgroup


gen emp_ogmint=emp if inlist(substr(naics,1,3),"211","213")
gen est_ogmint=est if inlist(substr(naics,1,3),"211","213")

bys year fips: egen emp_ogmin=sum(emp_ogmint)
bys year fips: egen est_ogmin=sum(est_ogmint)

replace emp_ogmin=0 if emp_ogmin==.
replace est_ogmin=0 if est_ogmin==.

duplicates drop year fips, force

replace ctyemp=ctyemp-emp_ogmin
replace ctyest=ctyest-est_ogmin

collapse (sum) ctyemp ctyest,by(year)
rename ctyemp emp
rename ctyest est

gen avgsize=emp/est

gen est2006_t=est if year==2006
gen emp2006_t=emp if year==2006
gen avgsize2006_t=avgsize if year==2006
egen emp2006=mean(emp2006_t)
egen est2006=mean(est2006_t)
egen avgsize2006=mean(avgsize2006_t)

gen sizeconstant=est*avgsize2006 // Counterfactual emp with constant avg size
gen estconstant=est2006*avgsize // Counterfactual emp with constant estab count

gen sizeconstant_gr=sizeconstant-emp2006
gen estconstant_gr=estconstant-emp2006
gen covar=(est-est2006)*(avgsize-avgsize2006)
gen truechange=emp-emp2006

gen test=sizeconstant_gr+estconstant_gr+covar

drop if year<2006

replace sizeconstant_gr=sizeconstant_gr/truechange
replace estconstant_gr=estconstant_gr/truechange
replace covar=covar/truechange

**** Now, ignore the covar term, which is small and uninterpretable

replace sizeconstant_gr=sizeconstant_gr/(1-covar)
replace estconstant_gr=estconstant_gr/(1-covar)

replace emp=100*emp/emp2006-100
replace sizeconstant_gr=sizeconstant_gr*emp
replace estconstant_gr=estconstant_gr*emp

gen zero=0

twoway (line emp year,lwidth(thick) lcolor(red) msymbol(i))/*
*/ (line sizeconstant_gr year,lwidth(thick) lpattern(dash) lcolor(green%75) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white))/*
*/xtitle("") xlabel(2006(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal) nogrid labsize(4.5)) ytitle("Relative to 2006 level (%)",size(4.5))/*
*/legend(label(1 "Total employment") label(2 "Holding establishment size constant") region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(6) keygap(1) rowgap(1))/*
*/subtitle("Excluding oil & gas mining",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)

graph save nonogmin,replace
label variable emp "Total employment"
label variable sizeconstant_gr "Holding establishment size constant"
export excel year emp sizeconstant_gr using ../../chartpack.xlsx,sheet("fig4a") firstrow(varlabels) sheetreplace

******** Note the version with all shale counties doesn't tell us much due to big GR emp drop


******* Now do boomtowns excluding ogmin
use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) //posgroup

keep if inlist(substr(naics,1,3),"211","213")

collapse (sum) emp est,by(year)
gen avgsize=emp/est

gen est2006_t=est if year==2006
gen emp2006_t=emp if year==2006
gen avgsize2006_t=avgsize if year==2006
egen emp2006=mean(emp2006_t)
egen est2006=mean(est2006_t)
egen avgsize2006=mean(avgsize2006_t)

gen sizeconstant=est*avgsize2006 // Counterfactual emp with constant avg size
gen estconstant=est2006*avgsize // Counterfactual emp with constant estab count

gen sizeconstant_gr=sizeconstant-emp2006
gen estconstant_gr=estconstant-emp2006
gen covar=(est-est2006)*(avgsize-avgsize2006)
gen truechange=emp-emp2006

gen test=sizeconstant_gr+estconstant_gr+covar

drop if year<2006

replace sizeconstant_gr=sizeconstant_gr/truechange
replace estconstant_gr=estconstant_gr/truechange
replace covar=covar/truechange

**** Now, ignore the covar term, which is small and uninterpretable

replace sizeconstant_gr=sizeconstant_gr/(1-covar)
replace estconstant_gr=estconstant_gr/(1-covar)

replace emp=100*emp/emp2006-100
replace sizeconstant_gr=sizeconstant_gr*emp
replace estconstant_gr=estconstant_gr*emp

gen zero=0

twoway (line emp year,lwidth(thick) lcolor(red) msymbol(i))/*
*/ (line sizeconstant_gr year,lwidth(thick) lpattern(dash) lcolor(green%75) msymbol(i)),/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white))/*
*/xtitle("") xlabel(2006(2)2014,angle(45) labsize(4.5))/*
*/ylabel(,angle(horizontal)  nogrid labsize(4.5)) ytitle("Relative to 2006 level (%)",size(4.5))/*
legend(label(1 "Total employment") label(2 "Holding establishment size constant") region(lcolor(white)) position(11) ring(0) cols(1) size(medlarge) symxsize(4) keygap(1) rowgap(1))
*/legend(off) subtitle("Oil & gas mining",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(2.5) xsize(3.25)
graph save ogmin,replace

label variable emp "Total employment"
label variable sizeconstant_gr "Holding establishment size constant"
export excel year emp sizeconstant_gr using ../../chartpack.xlsx,sheet("fig4b") firstrow(varlabels) sheetreplace




graph combine nonogmin.gph ogmin.gph, iscale(1)/*
subtitle("Margins of employment growth in boom towns",justification(left) margin(b+1 t) bexpand size(large))
*/ graphregion(color(white) margin(tiny))/*
*/note("Note: Total employment relative to year-2006 level. Covariance term shared out proportionally."/*
*/"Boom towns are Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. Oil & gas mining consists of NAICS 211 and 213.",size(4.5))/*
*/xsize(6.5) ysize(3)
graph export ../output/cbp_growthmargins.pdf,replace


*******************************************
* Chart: accounting for emp gains with change in est counts: by sector
use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) //posgroup

drop if substr(naics,4,1)=="/"
gen naicst=substr(naics,1,2)
destring naicst,gen(naics2)

* Define our supersectors, not exactly same as BLS
replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
replace naics2=60 if inlist(naics2,54,55,56) //PBS
replace naics2=65 if inlist(naics2,61,62) //Ed & health
replace naics2=70 if inlist(naics2,71,72) //L&H

foreach sec in 21 22 23 31 44 48 60 65 70 81 90 {
	preserve
	
		keep if naics2==`sec'

		duplicates drop year fips, force

		keep year fips shale emp est


		collapse (sum) emp est,by(year)
		*rename ctyemp emp
		*rename ctyest est

		gen avgsize=emp/est

		gen est2006_t=est if year==2006
		gen emp2006_t=emp if year==2006
		gen avgsize2006_t=avgsize if year==2006
		egen emp2006=mean(emp2006_t)
		egen est2006=mean(est2006_t)
		egen avgsize2006=mean(avgsize2006_t)

		gen sizeconstant=est*avgsize2006 // Counterfactual emp with constant avg size
		gen estconstant=est2006*avgsize // Counterfactual emp with constant estab count

		gen sizeconstant_gr=sizeconstant-emp2006
		gen estconstant_gr=estconstant-emp2006
		gen covar=(est-est2006)*(avgsize-avgsize2006)
		gen truechange=emp-emp2006

		gen test=sizeconstant_gr+estconstant_gr+covar

		drop if year<2006

		replace sizeconstant_gr=sizeconstant_gr/truechange
		replace estconstant_gr=estconstant_gr/truechange
		replace covar=covar/truechange

		**** Now, ignore the covar term, which is small and uninterpretable

		replace sizeconstant_gr=sizeconstant_gr/(1-covar)
		replace estconstant_gr=estconstant_gr/(1-covar)

		replace emp=100*emp/emp2006-100
		replace sizeconstant_gr=sizeconstant_gr*emp
		replace estconstant_gr=estconstant_gr*emp

		gen zero=0


		if "`sec'"=="21" {
			local secname="Mining"
			local fig="mining"
		}
		else if "`sec'"=="22" {
			local secname="Utilities"
			local fig="utilities"
		}
		else if "`sec'"=="23" {
			local secname="Construction"
			local fig="construction"
		}
		else if "`sec'"=="31" {
			local secname="Manufacturing"
			local fig="manufacturing"
		}
		else if "`sec'"=="44" {
			local secname="Retail trade"
			local fig="retail"
		}
		else if "`sec'"=="48" {
			local secname="Transp & warehousing"
			local fig="transp"
		}
		else if "`sec'"=="60" {
			local secname="Prof & business svcs"
			local fig="prof"
		}
		else if "`sec'"=="65" {
			local secname="Education & health"
			local fig="education"
		}
		else if "`sec'"=="70" {
			local secname="Leisure & hospitality"
			local fig="leisure"
		}
		else if "`sec'"=="81" {
			local secname="Other svcs"
			local fig="othersvcs"
		}
		else if "`sec'"=="90" {
			local secname="Other"
			local fig="other"
		}
		
			
		
		// if `sec'==xy {
		
			twoway (line emp year,lwidth(thick) lcolor(red) msymbol(i))/*
			*/ (line sizeconstant_gr year,lwidth(thick) lcolor(green%75) lpattern(dash) msymbol(i)),/*
			*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white))/*
			*/xtitle("") xlabel(2006(4)2014,angle(0) labsize(2.3)) xscale(r(2006 2014.5))/*
			*/ylabel(,angle(horizontal) nogrid labsize(2.3)) ytitle("Relative to 2006 level (%)",size(2.3))/*
			*/legend(label(1 "Total employment") label(2 "Holding establishment size constant") region(lcolor(white)) position(11) ring(0) cols(2) size(2.3) symxsize(6) bmargin(zero) keygap(1) rowgap(1))/*
			*/subtitle("`secname'",size(2.3) justification(left) margin(b+1 t) bexpand) xsize(2.1) ysize(2)
		/*}
		else {
			twoway (line emp year,lwidth(thick) msymbol(i))/*
			*/ (line sizeconstant_gr year,lwidth(thick) lpattern(dash) msymbol(i)),/*
			*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white))/*
			*/xtitle("") xlabel(2006(2)2014,angle(45) labsize(medlarge))/*
			*/ylabel(,angle(horizontal) nogrid labsize(medlarge)) ytitle("Relative to 2006 level (%)",size(medlarge))/*
			*/legend(off)/*
			*/subtitle("`secname'",size(*1.35) justification(left) margin(b+1 t) bexpand)
		}*/
		
		graph save margins`sec',replace
		
		label variable emp "Total employment"
		label variable sizeconstant_gr "Holding establishment size constant"
		
	restore
}	





grc1leg margins21.gph margins22.gph margins23.gph margins31.gph margins44.gph margins48.gph margins60.gph margins65.gph margins70.gph margins81.gph margins90.gph, rows(4) cols(3) iscale(1) position(12)/*
subtitle("Margins of sector employment growth in boom towns",justification(left) margin(b+1 t) bexpand size(medsmall))
*/ graphregion(color(white) margin(tiny))/*
*/note("Note: Total employment relative to year-2006 level. Covariance term shared out proportionally.""Includes Anadarko, Bakken, Eagle Ford, and Permian Basin."/*
*/"Source: County Business Patterns. NAICS sectors.",size(2.2)) name(g3,replace)
graph display g3,xsize(6.3) ysize(8.5)
graph export ../output/cbp_growthmargins_sec.pdf,replace





********************************************
* Chart: various industry shares, all plays

use "../data/intermediate data/cbp_panel",clear
keep if shale==1 | control==1 // Limit to control group choice set
drop if substr(naics,4,1)=="/"
gen naicst=substr(naics,1,2)
destring naicst,gen(naics2)

* Define our supersectors, not exactly same as BLS
replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
replace naics2=60 if inlist(naics2,54,55,56) //PBS
replace naics2=65 if inlist(naics2,61,62) //Ed & health
replace naics2=70 if inlist(naics2,71,72) //L&H

bys fips year naics2: egen sectoremp=sum(emp)
bys fips year naics2: egen sectorest=sum(est)
duplicates drop fips year naics2, force

preserve
	keep year fips ctyemp ctyest shale
	duplicates drop year fips,force
	gen naics2=0
	rename ctyemp sectoremp
	rename ctyest sectorest

	tempfile aggs
	save `aggs',replace
restore
keep year fips naics2 sectoremp sectorest shale
append using `aggs'

tempfile shalenonshale
save `shalenonshale',replace // This has shale and nonshale by sector

use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7)  //posgroup
replace shale=3
drop if substr(naics,4,1)=="/"
gen naicst=substr(naics,1,2)
destring naicst,gen(naics2)

* Define our supersectors, not exactly same as BLS
replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
replace naics2=60 if inlist(naics2,54,55,56) //PBS
replace naics2=65 if inlist(naics2,61,62) //Ed & health
replace naics2=70 if inlist(naics2,71,72) //L&H

bys fips year naics2: egen sectoremp=sum(emp)
bys fips year naics2: egen sectorest=sum(est)
duplicates drop fips year naics2, force

preserve
	keep year fips ctyemp ctyest shale
	duplicates drop year fips,force
	gen naics2=0
	rename ctyemp sectoremp
	rename ctyest sectorest

	tempfile aggs
	save `aggs',replace
restore
keep year fips naics2 sectoremp sectorest shale
append using `aggs'

append using `shalenonshale'
gen avgest=sectorest

collapse (sum) sectoremp sectorest (mean) avgest,by(year shale naics2)
keep if year==2006
gen avgsize=sectoremp/sectorest







********************************************
* Chart: sector growth, posgroup

use "../data/intermediate data/cbp_panel",clear
keep if inlist(region_id,1,3,4,7) //boom towns
drop if substr(naics,4,1)=="/"
gen naicst=substr(naics,1,2)
destring naicst,gen(naics2)

* Define our supersectors, not exactly same as BLS
replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
replace naics2=60 if inlist(naics2,54,55,56) //PBS
replace naics2=65 if inlist(naics2,61,62) //Ed & health
replace naics2=70 if inlist(naics2,71,72) //L&H

bys fips year naics2: egen sectoremp=sum(emp)
bys fips year naics2: egen sectorest=sum(est)
duplicates drop fips year naics2, force

keep year fips naics2 sectoremp sectorest

rename sectoremp emp
rename sectorest est

reshape wide emp est,i(year fips) j(naics2)
foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
	replace emp`i'=0 if emp`i'==.
	replace est`i'=0 if est`i'==.
}

collapse (mean) emp21-est90,by(year)
drop if year<2006

foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
	gen tm=emp`i' if year==2006
	gen te=est`i' if year==2006
	
	egen m=mean(tm)
	egen e=mean(te)
	
	replace emp`i'=100*emp`i'/m-100
	replace est`i'=100*est`i'/e-100
	
	drop tm te m e
}

order year emp*

reshape long emp est,i(year) j(naics2)
keep if year==2014



label define labs 21 "Mining" 22 "Utilities" 23 "Construction" 31 "Manufacturing" 44 "Retail trade" 48 "Tran & ware" 60 "Prof & biz" 65 "Ed & health" 70 "Leisure & hosp" 81 "Other svcs" 90 "Other"
label values naics2 labs
drop if naics2==90

graph bar emp est,over(naics2,label(labsize(4.5) angle(45)))/*
*/legend(order(1 "Employment" 2 "Establishments") region(lcolor(white)) position(2) ring(0) cols(1) size(4.5) symxsize(4) keygap(1))/*
*/bar(1,color(red)) bar(2,color(green%75))/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/ytitle("Relative to 2006 average (%)""",size(4.5)) ylabel(,angle(horizontal) nogrid labsize(4.5))/*
subtitle("Sector employment shares, boom towns vs. non-shale counties",justification(left) margin(b+1 t l-11) bexpand size(*1.35))
*/note("Note: 2006-2014 growth of average county-level employment and establishment counts. Boom towns are Anadarko,""Bakken, Eagle Ford, and Permian Basin. Residual industries omitted."/*
*/"Source: County Business Patterns. NAICS sectors.",size(medlarge)) xsize(6.5) ysize(3)
graph export ../output/cbp_sec_posgroup.pdf,replace

label variable emp "Employment"
label variable est "Establishments"
export excel naics2 emp est using ../../chartpack.xlsx,sheet("fig3") firstrow(varlabels) sheetreplace

********************************************
* Chart: sector growth, control set

use "../data/intermediate data/cbp_panel",clear
keep if control==1
drop if substr(naics,4,1)=="/"
gen naicst=substr(naics,1,2)
destring naicst,gen(naics2)

* Define our supersectors, not exactly same as BLS
replace naics2=90 if inlist(naics2,11,42,51,52,53,92,95,99) //Other stuff
replace naics2=60 if inlist(naics2,54,55,56) //PBS
replace naics2=65 if inlist(naics2,61,62) //Ed & health
replace naics2=70 if inlist(naics2,71,72) //L&H

bys fips year naics2: egen sectoremp=sum(emp)
bys fips year naics2: egen sectorest=sum(est)
duplicates drop fips year naics2, force

keep year fips naics2 sectoremp sectorest

rename sectoremp emp
rename sectorest est

reshape wide emp est,i(year fips) j(naics2)
foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
	replace emp`i'=0 if emp`i'==.
	replace est`i'=0 if est`i'==.
}

collapse (mean) emp21-est90,by(year)
drop if year<2006

foreach i in 21 22 23 31 44 48 60 65 70 81 90 {
	gen tm=emp`i' if year==2006
	gen te=est`i' if year==2006
	
	egen m=mean(tm)
	egen e=mean(te)
	
	replace emp`i'=100*emp`i'/m-100
	replace est`i'=100*est`i'/e-100
	
	drop tm te m e
}

order year emp*

reshape long emp est,i(year) j(naics2)
keep if year==2014



label define labs 21 "Mining" 22 "Utilities" 23 "Construction" 31 "Manufacturing" 44 "Retail trade" 48 "Tran & ware" 60 "Prof & biz" 65 "Ed & health" 70 "Leisure & hosp" 81 "Other svcs" 90 "Other"
label values naics2 labs
drop if naics2==90

graph bar emp est,over(naics2,label(labsize(4.5) angle(45)))/*
*/legend(order(1 "Employment" 2 "Establishments") region(lcolor(white)) position(5) ring(0) cols(1) size(4.5) symxsize(4) keygap(1))/*
*/bar(1,color(red)) bar(2,color(green%75))/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/ytitle("Relative to 2006 average (%)""",size(4.5)) ylabel(,angle(horizontal) nogrid labsize(4.5))/*
subtitle("Sector employment shares, boom towns vs. non-shale counties",justification(left) margin(b+1 t l-11) bexpand size(*1.35))
*/note("Note: 2006-2014 growth of average county-level employment and establishment counts. Excludes states with shale""counties and states adjacent to shale counties. Residual industries omitted."/*
*/"Source: County Business Patterns. NAICS sectors.",size(medlarge)) xsize(6.5) ysize(3)
graph export ../output/cbp_sec_control.pdf,replace

label variable emp "Employment"
label variable est "Establishments"


********************************************
* Chart: manufacturing growth by play

use "../data/intermediate data/cbp_panel",clear
keep if substr(naics,1,2)=="31" & substr(naics,3,1)=="-"

keep year region_id fips emp est

collapse (mean) emp est,by(year region_id)
drop if year<2006

gen tm=emp if year==2006
gen te=est if year==2006

bys region_id: egen m=max(tm)
bys region_id: egen e=max(te)

replace emp=100*emp/m-100
replace est=100*est/e-100 

keep if year==2014

keep year region_id emp est 


graph bar emp est,over(region_id,label(labsize(4.5) angle(45)))/*
*/legend(order(1 "Employment" 2 "Establishments") region(lcolor(white)) position(2) ring(0) cols(1) size(4.5) symxsize(4) keygap(1))/*
*/bar(1,color(red)) bar(2,color(green%75))/*
*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none))/*
*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none))/*
*/ytitle("Relative to 2006 average (%)""",size(4.5)) ylabel(,angle(horizontal) nogrid labsize(4.5))/*
subtitle("Sector employment shares, boom towns vs. non-shale counties",justification(left) margin(b+1 t l-11) bexpand size(*1.35))
*/note("Note: 2006-2014 growth of average county-level employment and establishment counts."/*
*/"Source: County Business Patterns. Manufacturing (NAICS 31-33) only.",size(medlarge)) xsize(6.5) ysize(3)
graph export ../output/cbp_mfg_bar.pdf,replace

