// Process CBP data and attach shale county identifiers
// CBP processing consists primarily of imputing censored data

***** RUN THIS CODE FROM ITS OWN DIRECTORY

***** CHANGE THE LINE BELOW; define global for where to get CBP source data files 
global cbp="[path to CBP raw data]"



clear
********************************************************************************
* 1. formatting Shale Play County data to use fipstate and fipscty codes 
*    instead of StateID and CountyID
********************************************************************************
import excel using "../data/raw data/dpr-data.xlsx", firstrow sheet ("RegionCounties")


destring StateID, gen (fipstate)
destring StateID, replace

replace fipstate=40 if (StateID==35) // OK
replace fipstate=48 if (StateID==42) // TX	
replace fipstate=24 if (StateID==19) // MD	
replace fipstate=36 if (StateID==31) // NY
replace fipstate=39 if (StateID==34) // OH
replace fipstate=42 if (StateID==37) // PA
replace fipstate=54 if (StateID==47) // WV
replace fipstate=30 if (StateID==25) // MT
replace fipstate=38 if (StateID==33) // ND
replace fipstate=5 if (StateID==3)   // AR
replace fipstate=22 if (StateID==17) // LA
replace fipstate=8 if (StateID==5)   // CO
replace fipstate=20 if (StateID==15) // KS
replace fipstate=31 if (StateID==26) // NE
replace fipstate=56 if (StateID==49) // WY
replace fipstate=35 if (StateID==30) // NM
********************************************************************************




********************************************************************************
*generating a unique ID, combination of fipstate & fipscty numbers
********************************************************************************
tostring fipstate, replace
gen fips = fipstate + CountyID
destring fips, replace
destring CountyID, gen (fipscty)
destring fipstate, replace
drop StateID CountyID


save "../data/intermediate data/County Codes.dta", replace
********************************************************************************


********************************************************************************
* 2. Cleaning and Merging County Business Pattern data 
*    to only include pertinent NAISC
********************************************************************************
clear



forvalues i=-1/14 {

	if `i'<10 & `i'>-1 {
		import delimited $cbp/cbp0`i'co.txt,clear
	}
	else if `i'==-1 {
		import delimited $cbp/cbp99co.txt,clear
	}
	else {
		import delimited $cbp/cbp`i'co.txt,clear
	}
	
	*drop if fipscty==999 // Statewide county code, dont drop these! theyre not redundant, they are just countyless employees
	
	gen year=2000+`i'

	******* First, sort out NAICS sectors
	
	*Spin off the 3-digit pieces I will need later
	preserve
		keep if substr(naics,4,1)=="/" & (substr(naics,1,1)=="3" | substr(naics,1,2)=="21")
		save trash_3digit,replace
	restore
	
	
	*Now focus on 2-digit
	keep if substr(naics,3,1)=="-"
	
	 

*There are two possible problems: missing county emp, and missing sector x county emp.
* First deal with county level. Find average employment by empflag for whole sample
* excluding missings. Apply that to missings. Total up nationwide employment and compare to
* national employment from national cbp file. Note discrepancy. Share out discrepancy among missing
* counties based on estimated emp shares. Then get final number, which will ensure that the total of
* county employment equals true national employment, subject to rounding.

* Then deal with sector x county missings. Find average employment by empflag x sector for whole sample
* excluding missings. Apply that to missings. Total up to county level and note discrepancy.
* Share out discrepancy among missings based on estimated emp. Then get final number, which will
* add up appropriately.



	preserve 
		keep if empflag==""
		replace empflag="A" if emp<20
		replace empflag="B" if emp>19 & emp<100
		replace empflag="C" if emp>99 & emp<250
		replace empflag="E" if emp>249 & emp<500
		replace empflag="F" if emp>499 & emp<1000
		replace empflag="G" if emp>999 & emp<2500
		replace empflag="H" if emp>2499 & emp<5000
		replace empflag="I" if emp>4999 & emp<10000
		replace empflag="J" if emp>9999 & emp<25000
		replace empflag="K" if emp>24999 & emp<50000
		replace empflag="L" if emp>49999 & emp<100000
		replace empflag="M" if emp>99999
		
		collapse (mean) emp,by(naics empflag)
		sort naics empflag
		rename emp avgemp
		
		tempfile bins
		save `bins',replace
	restore
	
	sort naics empflag
	merge m:1 naics empflag using `bins'
	drop if _merge==2
	drop _merge
	
	*What if a sector x sizebin cell has no average? Choose the midpoint arbitrarily
	replace avgemp=9.5 if empflag=="A" & avgemp==.
	replace avgemp=59.5 if empflag=="B" & avgemp==.
	replace avgemp=174.5 if empflag=="C" & avgemp==.
	replace avgemp=374.5 if empflag=="E" & avgemp==.
	replace avgemp=749.5 if empflag=="F" & avgemp==.
	replace avgemp=1749.5 if empflag=="G" & avgemp==.
	replace avgemp=3749.5 if empflag=="H" & avgemp==.
	replace avgemp=7499.5 if empflag=="I" & avgemp==.
	replace avgemp=17499.5 if empflag=="J" & avgemp==.
	replace avgemp=37499.5 if empflag=="K" & avgemp==.
	replace avgemp=74999.5 if empflag=="L" & avgemp==.
	replace avgemp=100000 if empflag=="M" & avgemp==. //Choosing lower bound here, arbitrarily. Will be raised to produce correct aggregate.
	
	*In 2014 on, it is possible to have an S flag with no size guideline at all. Build up from estab distribution and midpoints
	replace avgemp=n1_4*2.5+n5_9*7+n10_19*14.5+n20_49*34.5+n50_99*74.5+n100_249*174.5+n250_499*374.5+n500_999*749.5+n1000_1*1249.5+n1000_2*1999.5+n1000_3*3749.5+n1000_4*5000 if empflag=="S"
	
	count if avgemp==. & empflag!=""
	
	replace emp=avgemp if empflag!="" // Guess based on sector average elsewhere, should be quite close given bins
	
	
	***** First impute the missing county totals
	
	preserve
		if `i'<10 & `i'>-1 {
			import delimited $cbp/national_ts/cbp0`i'us.txt,clear
		}
		else if `i'==-1 {
			import delimited $cbp/national_ts/cbp99us.txt,clear
		}
		else {
			import delimited $cbp/national_ts/cbp`i'us.txt,clear
		}
	
		if `i'>7 {
			keep if lfo=="-"
		}

		keep if naics=="------"
		
		keep naics emp
		rename emp aggsecemp
		sort naics
		
		tempfile national
		save `national',replace
		
		gen year=2000+`i'
		drop naics
		rename aggsecemp aggemp
		
		sort year
		tempfile national2
		save `national2',replace
	restore
	
	sort naics
	
	merge m:1 naics using `national'
	
	
	drop _merge
	
	
	gen ctylevel=(naics=="------")
	gen ctyemp=emp*ctylevel
	
	egen aggsecemp_est=sum(ctyemp)
	gen discrepancy=aggsecemp_est-aggsecemp
	
	*Share out the discrepancy
	gen missemp=emp if empflag!="" & naics=="------"
	egen missempsum=sum(missemp)
	gen share=missemp/missempsum
	
	replace emp=emp-share*discrepancy if naics=="------" & empflag!=""
	
	drop ctylevel ctyemp aggsecemp_est aggsecemp discrepancy missemp missempsum share

	
	***** Next impute missing county x sector figures
	gen sectoremp=emp if naics!="------"
	bys fipstate fipscty: egen ctyemp_est=sum(sectoremp) //Estimated county employment based on imputed missings
	
	gen ctyind=(naics=="------")
	gen ctyemp_t=ctyind*emp
	
	bys fipstate fipscty: egen ctyemp=sum(ctyemp_t) //Actual county employment
	
	drop sectoremp ctyind ctyemp_t sectoremp
	gen discrepancy=ctyemp_est-ctyemp
		
	*Share out the discrepancy
	gen missemp=emp if empflag!="" & naics!="------"
	bys fipstate fipscty: egen missempsum=sum(missemp)
	gen share=missemp/missempsum
	
	replace emp=emp-share*discrepancy if empflag!="" & naics!="------"
	drop missemp missempsum share avgemp ctyemp_est ctyemp discrepancy
	
	save trash_2digit,replace
	
	
	***** Now do special industries: ogmin and ogmfg
	use trash_3digit,clear
	
	preserve 
		keep if empflag==""
		replace empflag="A" if emp<20
		replace empflag="B" if emp>19 & emp<100
		replace empflag="C" if emp>99 & emp<250
		replace empflag="E" if emp>249 & emp<500
		replace empflag="F" if emp>499 & emp<1000
		replace empflag="G" if emp>999 & emp<2500
		replace empflag="H" if emp>2499 & emp<5000
		replace empflag="I" if emp>4999 & emp<10000
		replace empflag="J" if emp>9999 & emp<25000
		replace empflag="K" if emp>24999 & emp<50000
		replace empflag="L" if emp>49999 & emp<100000
		replace empflag="M" if emp>99999
		
		collapse (mean) emp,by(naics empflag)
		sort naics empflag
		rename emp avgemp
		
		tempfile bins
		save `bins',replace
	restore
	
	sort naics empflag
	merge m:1 naics empflag using `bins'
	drop if _merge==2
	drop _merge
	
	*What if a sector x sizebin cell has no average? Choose the midpoint arbitrarily
	replace avgemp=9.5 if empflag=="A" & avgemp==.
	replace avgemp=59.5 if empflag=="B" & avgemp==.
	replace avgemp=174.5 if empflag=="C" & avgemp==.
	replace avgemp=374.5 if empflag=="E" & avgemp==.
	replace avgemp=749.5 if empflag=="F" & avgemp==.
	replace avgemp=1749.5 if empflag=="G" & avgemp==.
	replace avgemp=3749.5 if empflag=="H" & avgemp==.
	replace avgemp=7499.5 if empflag=="I" & avgemp==.
	replace avgemp=17499.5 if empflag=="J" & avgemp==.
	replace avgemp=37499.5 if empflag=="K" & avgemp==.
	replace avgemp=74999.5 if empflag=="L" & avgemp==.
	replace avgemp=100000 if empflag=="M" & avgemp==. //Choosing lower bound here, arbitrarily. Will be raised to produce correct aggregate.
	count if avgemp==. & empflag!=""
	
	*In 2014 on, it is possible to have an S flag with no size guideline at all. Build up from estab distribution and midpoints
	replace avgemp=n1_4*2.5+n5_9*7+n10_19*14.5+n20_49*34.5+n50_99*74.5+n100_249*174.5+n250_499*374.5+n500_999*749.5+n1000_1*1249.5+n1000_2*1999.5+n1000_3*3749.5+n1000_4*5000 if empflag=="S"
	
	
	replace emp=avgemp if empflag!="" // Guess based on sector average elsewhere, should be quite close given bins
	
	*Now go get sectors
	append using trash_2digit
	
	*first do mining
	preserve
		keep if substr(naics,1,2)=="21"
		gen sectoremp=emp if naics!="21----"
		bys fipstate fipscty: egen ctyemp_est=sum(sectoremp) //Estimated sector employment based on imputed missings
		
		gen ctyind=(naics=="21----")
		gen ctyemp_t=ctyind*emp
		bys fipstate fipscty: egen ctyemp=sum(ctyemp_t) //Actual county sector employment
	
		drop sectoremp ctyind ctyemp_t
		gen discrepancy=ctyemp_est-ctyemp
		
		*Share out the discrepancy
		gen missemp=emp if empflag!="" & naics!="21----"
		bys fipstate fipscty: egen missempsum=sum(missemp)
		gen share=missemp/missempsum
		
		replace emp=emp-share*discrepancy if empflag!="" & naics!="21----"
		drop missemp missempsum share avgemp ctyemp_est ctyemp discrepancy
		
		drop if naics=="21----"
		
		tempfile min
		save `min',replace
	restore
	
	*now do mfg
	keep if substr(naics,1,1)=="3"
	gen sectoremp=emp if naics!="31----"
	bys fipstate fipscty: egen ctyemp_est=sum(sectoremp) //Estimated sector employment based on imputed missings
	
	gen ctyind=(naics=="31----")
	gen ctyemp_t=ctyind*emp
	bys fipstate fipscty: egen ctyemp=sum(ctyemp_t) //Actual county sector employment

	drop sectoremp ctyind ctyemp_t
	gen discrepancy=ctyemp_est-ctyemp
	
	*Share out the discrepancy
	gen missemp=emp if empflag!="" & naics!="31----"
	bys fipstate fipscty: egen missempsum=sum(missemp)
	gen share=missemp/missempsum
	
	replace emp=emp-share*discrepancy if empflag!="" & naics!="31----"
	drop missemp missempsum share avgemp ctyemp_est ctyemp discrepancy
	
	drop if naics=="31----"
	
	
	*** All done, stack everything
	append using `min'
	append using trash_2digit
	
	
	****************************
	* Result is a state-county by naics panel, with duplication for county aggregates and ogmin/ogmfg 3-digits
	
	* Now turn into a more useful panel setup by moving county employment to a separate variable
	preserve
		keep if naics=="------"
		keep fipstate fipscty emp est empflag
		rename emp ctyemp
		rename est ctyest
		rename empflag ctyempflag
		
		sort fipstate fipscty
		tempfile countyagg
		save `countyagg',replace
	restore
	
	drop if naics=="------"
	sort fipstate fipscty
	merge m:1 fipstate fipscty using `countyagg'
	drop _merge

	erase trash_2digit.dta
	erase trash_3digit.dta
	
	drop censtate cencty
	
	sort year
	merge m:1 year using `national2'
	drop _merge
	
	
	if "`i'"=="-1" {
		save "../data/intermediate data/cbp_panel",replace
	}
	else {
		append using "../data/intermediate data/cbp_panel"
		save "../data/intermediate data/cbp_panel",replace
	}
	
	
}

*A quick diagnostic
preserve
	duplicates drop fipstate fipscty year,force
	collapse (sum) ctyemp (mean) aggemp,by(year)
	
	gen discrepancy=ctyemp-aggemp
	sum discrepancy,d
	
	keep year ctyemp
	rename ctyemp aggemp
	sort year
	
	tempfile aggs
	save `aggs',replace
restore

*Our measure of aggregate employment will be the sum of the counties, which is extremely close to true aggregate employment by construction
drop aggemp
sort year
merge m:1 year using `aggs'
drop _merge

* Just get an estimate of the pervasiveness of censoring
preserve
	drop if substr(naics,3,1)!="-"
	gen censored=(empflag!="")
	gen censemp_t=emp*censored
	
	bys year: egen censemp=sum(censemp_t)
	gen censhare=censemp/aggemp
	duplicates drop year,force
	keep year censhare
	list
restore
*looks to be about ~1 to 3% of employment

preserve
	drop if substr(naics,4,1)!="/"
	gen censored=(empflag!="")
	gen censemp_t=emp*censored
	
	bys year: egen censemp=sum(censemp_t)
	gen censhare=censemp/aggemp
	duplicates drop year,force
	keep year censhare
	list
restore




	   
********************************************************************************	   
* Creating a unique ID with the combination of FIPS State and County codes	   
********************************************************************************
		tostring fipscty, gen (fips2)
		replace fips2 = "0"+fips2 if fipscty<100
		replace fips2 = "0"+fips2 if fipscty<10

		tostring fipstate, gen (fips1)

		gen fips = fips1 + fips2
		destring fips, replace
		drop fips1 fips2
		order fips fipstate fipscty	   

preserve
	duplicates drop year fips,force
	gen censored=(ctyempflag!="")
	gen censemp_t=ctyemp*censored
	
	bys year: egen censemp=sum(censemp_t)
	gen censhare=censemp/aggemp
	duplicates drop year,force
	keep year censhare
	list
restore

********************************************************************************
* 3. Merge CBP data sets with County Codes;
********************************************************************************
merge m:1 fipstate fipscty using "../data/intermediate data/County Codes.dta"
*keep if _merge==3
drop _merge


********************************************************************************
* 4. Labeling Variables in data set
********************************************************************************
label var year "Year"
label var emp_nf "Total Mid-March Employees Noise Flag"
label var qp1_nf "Total First Quarter Payroll Noise Flag"
label var ap_nf "Total Annual Payroll Noise Flag"
label var naics "Industry Code: 6-digit NAICS code"
label var fipscty "FIPS County Code"
label var fipstate "FIPS State Code"
label var empflag "Data Suppression Flag"
label var emp "Total Mid-March Employees"
label var ap "Total Annual Payroll ($1,000)"
label var qp1 "First Quarter Payroll ($1000)"
label var est "Total Number of Establishments" 
label var n1_4 "Number of Establishments: Employment Size Class: 1-4 Employees"
label var n5_9 "Number of Establishments: Employment Size Class: 5-9 Employees"
label var n10_19 "Number of Establishments: Employment Size Class: 10-19 Employees"
label var n20_49 "Number of Establishments: Employment Size Class: 20-49 Employees"
label var n50_99 "Number of Establishments: Employment Size Class: 50-99 Employees"
label var n100_249 "Number of Establishments: Employment Size Class: 100-249 Employees"
label var n250_499 "Number of Establishments: Employment Size Class: 250-499 Employees"
label var n500_999 "Number of Establishments: Employment Size Class: 500-999 Employees"
label var n1000 "Number of Establishments: Employment Size Class: 1,000 or More Employees"
label var n1000_1 "Number of Establishments: Employment Size Class: 1,000-1,499 Employees"
label var n1000_2 "Number of Establishments: Employment Size Class: 1,500-2,4999 Employees"
label var n1000_3 "Number of Establishments: Employment Size Class: 2,500-4,999 Employees" 
label var n1000_4 "Number of Establishments: Employment Size Class: 5,000 or More Employeees"
label var ctyemp "Total county employment"
label var ctyest "Total county estab count"
label var aggemp "Total U.S. employment"

********************************************************************************





********************************************************************************
* 5. Creating value labels for fipstate
********************************************************************************
label define fipstatelabel ///
		1 "Alabama" ///
		2 "Alaska" ///
		4 "Arizona" ///
		5 "Arkansas" ///
		6 "California" ///
		8 "Colorado" ///
		9 "Connecticut" ///
		10 "Delaware" ///
		11 "District of Columbia" ///
		12 "Florida" ///
		13 "Georgia" ///
		15 "Hawaii" ///
		16 "Idaho" ///
		17 "Illinois" ///
		18 "Indiana" ///
		19 "Iowa" ///
		20 "Kansas" ///
		21 "Kentucky" ///
		22 "Louisiana" ///
		23 "Maine" ///
		24 "Maryland" ///
		25 "Massachusetts" ///
		26 "Michigan" ///
		27 "Minnesota" ///
		28 "Mississippi" ///
		29 "Missouri" ///
		30 "Montana" ///
		31 "Nebraska" ///
		32 "Nevada" ///
		33 "New Hampshire" ///
		34 "New Jersey" ///
		35 "New Mexico" ///
		36 "New York" ///
		37 "North Carolina" ///
		38 "North Dakota" ///
		39 "Ohio" ///
		40 "Oklahoma" ///
		41 "Oregon" ///
		42 "Pennsylvania" ///
		44 "Rhode Island" ///
		45 "South Carolina" ///
		46 "South Dakota" ///
		47 "Tennessee" ///
		48 "Texas" ///
		49 "Utah" ///
		50 "Vermont" ///
		51 "Virginia" ///
		53 "Washington" ///
		54 "West Virginia" ///
		55 "Wisconsin" ///
		56 "Wyoming" 

label values fipstate fipstatelabel
********************************************************************************




********************************************************************************
* 6. Creating value labels for region_id
********************************************************************************
gen region_id=0
replace region_id = 1 if Region=="Anadarko Region"
replace region_id = 2 if Region=="Appalachia Region"
replace region_id = 3 if Region=="Bakken Region"
replace region_id = 4 if Region=="Eagle Ford Region"
replace region_id = 5 if Region=="Haynesville Region"
replace region_id = 6 if Region=="Niobrara Region"
replace region_id = 7 if Region=="Permian Region"


label define regionidlabel ///
0 "Non-Shale"		/// 
1 "Anadarko" ///
2 "Appalachia" ///
3 "Bakken" ///
4 "Eagle Ford" /// 
5 "Haynesville" /// 
6 "Niobrara" /// 
7 "Permian"

label values region_id regionidlabel 
label var region_id "Region"
drop Region

gen shale=(region_id!=0)
label variable shale "Shale region dummy"
********************************************************************************


*****************************************************
* Identify control group set

gen control=1 if inlist(fipstate,1,4,6,9,10,12,13,15,16,17)
replace control=1 if inlist(fipstate,18,19,23,26,27,28,29,32,33,34)
replace control=1 if inlist(fipstate,37,41,44,45,47,50,53,55)

replace control=0 if control!=1
label variable control "State is included in control group choice set"



********************************************************************************
* 7. Saving dataset;
********************************************************************************
*keep fips Year fipstate fipscty naics emp qp1 ap est County region_id
rename County county
order year region_id fipstate county naics emp ap qp1 est region_id
sort fips naics year

save "../data/intermediate data/cbp_panel_99",replace
drop if year<2000 
save "../data/intermediate data/cbp_panel",replace
********************************************************************************




