/*
USDA Quick Stats, https://quickstats.nass.usda.gov

To get farm count:
Program: Census
Sector: Economics
Group: Farms & Land & Assets
Commodity: Farm operations
Category: Operations
Data item: Farm operations - Number of operations
Domain: Total
Geographic level: County 
State: Don't select anything
Year: 2002, 2007, 2012, 2017

To get hired worker count:
Program: CensusSector: EconomicsGroup: Expenses
Commodity: Labor
Category: Workers
Data item: Labor, hired: Number of workers
Domain: Total
Geographic level: County
State: Leave blank
Year: 2002, 2007, 2012, 2017
Period type: Annual
Period: Year

Do again for state-level.


*/

********************************************************************************
* 1. Farm count by county
********************************************************************************

import delimited "../data/raw data/farms.csv",clear

replace value=subinstr(value,",","",.)
destring value, replace

keep year stateansi state countyansi county value 
rename value farms
rename stateansi st 
rename countyansi cty

sort year st cty
drop if cty==.
tempfile farms
save `farms',replace

********************************************************************************
* 2. Worker count by county
********************************************************************************

import delimited "../data/raw data/farm_workers.csv",clear

replace value=subinstr(value,",","",.)

destring value, replace force
*There are 158 (D) values out of 12,285 observations.

keep year stateansi countyansi value 
rename value emp
rename stateansi st 
rename countyansi cty 
drop if cty==.

sort year st cty
merge 1:1 year st cty using `farms'
drop _merge 

gen missing=(emp==.)

** Will use a constant emp per missing-emp estab assumption for imputation
gen t=missing*farms
bys year state: egen farms_t=sum(t)
gen missing_share=t/farms_t 
drop t farms_t 

tempfile farms_emp
save `farms_emp',replace


********************************************************************************
* 3. State-level hired workers for imputation
********************************************************************************

import delimited "../data/raw data/farm_workers_state.csv",clear
replace value=subinstr(value,",","",.)
keep year stateansi value
destring value,replace
rename value emp_st 
rename stateansi st 

sort year st 
merge 1:m year st using `farms_emp'
keep if _merge==3
drop _merge 

bys year st: egen emp_st_sum=sum(emp)
gen diff=emp_st-emp_st_sum

replace emp=diff*missing_share if missing==1 // Assign employment to the county based on the county's share of farms among counties with missing employment.

keep year st cty emp state county farms missing 
bys st cty: egen imputed=max(missing)
rename st fipstate
rename cty fipscty
sort fipstate fipscty 


********************************************************************************
* 4. Merge in shale county identifiers and label
********************************************************************************

merge m:1 fipstate fipscty using "../data/intermediate data/County Codes.dta"
drop _merge 

gen region_id=0
replace region_id = 1 if Region=="Anadarko Region"
replace region_id = 2 if Region=="Appalachia Region"
replace region_id = 3 if Region=="Bakken Region"
replace region_id = 4 if Region=="Eagle Ford Region"
replace region_id = 5 if Region=="Haynesville Region"
replace region_id = 6 if Region=="Niobrara Region"
replace region_id = 7 if Region=="Permian Region"


label define regionidlabel ///
0 "Non-Shale"		/// 
1 "Anadarko" ///
2 "Appalachia" ///
3 "Bakken" ///
4 "Eagle Ford" /// 
5 "Haynesville" /// 
6 "Niobrara" /// 
7 "Permian"

label values region_id regionidlabel 
label var region_id "Region"
drop Region

gen shale=(region_id!=0)
label variable shale "Shale region dummy"

*****************************************************
* Identify control group set

gen control=1 if inlist(fipstate,1,4,6,9,10,12,13,15,16,17)
replace control=1 if inlist(fipstate,18,19,23,26,27,28,29,32,33,34)
replace control=1 if inlist(fipstate,37,41,44,45,47,50,53,55)

replace control=0 if control!=1
label variable control "State is included in control group choice set

drop fips
gen fips=1000*fipstate+fipscty

save "../data/intermediate data/farms",replace
