/*
This file picks up RDC table output files tableA3_RyanDecker_T13T26 and table5_RyanDecker_T13T26 then makes charts 
of cumulative employment year effects.
*/



* Get individual plays
import delimited "tableA3_RyanDecker_T13T26.csv", varnames(2) rowrange(2:31) stringcols(1) numericcols(2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21) clear
drop if v1==""

gen year=substr(v1,18,4)
destring year,force replace
order year
drop v1 

tempfile plays
save `plays',replace


* Get all plays and pos group
import delimited "table5_RyanDecker_T13T26.csv", varnames(2) rowrange(2:31) stringcols(1) numericcols(2 3 4 5 6 7 8 9) clear 
drop if v1==""

gen year=substr(v1,18,4)
destring year,force replace
order year
drop v1


merge 1:1 year using `plays'
drop _merge
graph set eps fontface "Times"
graph set window fontface "Times"
graph set ps fontface "Times"

foreach region in all /*anadarko bakken*/ eagle haynesville niobrara permian appalachia posgroup {

	preserve
	keep year `region'*
	
	gen greenfields=100*(`region'post7_inc+`region'post7_bir)
	label variable greenfields "New establishments"

	gen startups=100*`region'post7_bir
	label variable startups "New firms"

	gen total=100*`region'all
	label variable total "Total employment"

	*drop if year==2000
	
	gen zero=0
	local regionname="`temptest'"
	local leg="legend(off)"

	local box=12
	if "`region'"=="all" {
		local regionname="All regions"
		local statsig="statistically significant from 2008 on"
		local leg=""
		local fig="7"
		local top="20"
		
	}
	if "`region'"=="anadarko" {
		local regionname="Anadarko"
		local statsig="statistically significant from ZZZZ on"
	}
	if "`region'"=="bakken" {
		local regionname="Bakken"
		local statsig="statistically significant from ZZZZ on"
	}
	if "`region'"=="eagle" {
		local regionname="Eagle Ford"
		local statsig="statistically significant from 2010 on"
		local fig="A4c"
	}
	if "`region'"=="haynesville" {
		local regionname="Haynesville"
		local statsig="statistically significant in 2003, 2004, and 2010-2012" 
		local fig="A4d"
	}
	if "`region'"=="niobrara" {
		local regionname="Niobrara"
		local statsig="statistically significant in 2010"
		local fig="A4e"
	}
	if "`region'"=="permian" {
		local regionname="Permian Basin"
		local statsig="statistically significant from 2009 on"
		local fig="A4f"
	}
	if "`region'"=="appalachia" {
		local regionname="Appalachia"
		local statsig="statistically significant in 2010"
		local fig="A4b"
	}
	if "`region'"=="posgroup" {
		local regionname="Boom towns"
		local statsig="statistically significant from 2008 on. Anadarko, Bakken, Eagle Ford, and Permian Basin"
		local leg=""
		local fig="A4a"
		local top=40
	}
	
	
	if "`region'"=="all" | "`region'"=="posgroup" {
		*Big version
		twoway (rarea total greenfields year,color(red) ) (rarea greenfields startups year,color(green%75))/*
		*/ (rarea startups zero year,color(black)),/*
		*/ylabel(0(5)`top',angle(horizontal) labsize(4.5) nogrid) ytitle("Percent of 2006 employment" "",size(4.5)) xscale(r(1999.5 2014.5)) yscale(r(-2 20))/*
		*/ graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none)) xtitle("") xlabel(2000(2)2014,labsize(4.5))/*
		*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none) ilstyle(none)) /*
		title("Employment by establishment type: `regionname'")
		subtitle("Shale counties versus control group")
		*/ legend(label(1 "Total") label(2 "New establishments") label(3 "New firms") region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(4) keygap(1)) /*
		*/ `leg' /*
		*/note("Employment scaled by 2006 county employment. Regression compares treatment and control counties with year"/*
		*/"effects. New establishments are establishments born after 2006. New firms are firms born after 2006."/*
		*/"Author calculations from LBD. Oil and gas mining (NAICS 211, 213) excluded."/*
		*/"Total employment is `statsig'.",size(medlarge)) xsize(6.5) ysize(3)
		graph export area_`region'.pdf,replace
	}
	
	* Small version
	twoway (rarea total greenfields year,color(red) ) (rarea greenfields startups year,color(green%75))/*
	*/ (rarea startups zero year,color(black)),/*
	*/ylabel(-10(10)50,angle(horizontal) labsize(4.5) nogrid) ytitle("Percent of 2006 employment",size(4.5) /*height(13)*/) xscale(r(1999.5 2014.5)) yscale(r(-10 50))/*
	*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white) lstyle(none) ilstyle(none)) xtitle("") xlabel(2002(4)2014,labsize(4.5))/*
	*/plotregion(color(white) icolor(white) fcolor(white) ifcolor(white) lstyle(none)) /*
	title("Employment by establishment type: `regionname'")
	*/subtitle("`regionname'",size(4.5) justification(left) margin(b+1 t) bexpand) /*
	*/ legend(label(1 "Total") label(2 "New establishments") label(3 "New firms") region(lcolor(white)) position(11) ring(0) cols(1) size(4.5) symxsize(4) keygap(1)) /*
	*/ `leg' /*
	note("Total employment is `statsig'.",size(medium))*/ xsize(3.25) ysize(2.75)
	graph save `region',replace
	
	label variable total "Total"
	label variable greenfields "New establishments"
	label variable startups "New firms"
	*export excel year total greenfields startups using $chartpack\chartpack.xlsx,sheet("fig`fig'") firstrow(varlabels) sheetreplace
		
	restore

}

graph combine posgroup.gph appalachia.gph eagle.gph haynesville.gph niobrara.gph permian.gph, iscale(.5)/*
*/ rows(3) graphregion(color(white) margin(tiny))/*
*/note("Employment scaled by 2006 county employment. Regression compares treatment and control counties with" /*
*/"year effects. New establishments are establishments born after 2006. New firms are firms born after 2006." /*
*/" 'Boom towns' are Permian, Anadarko, Eagle Ford, and Bakken plays. Author calculations from LBD." /*
*/"Oil and gas mining (NAICS 211, 213) excluded.",size(2.25)) /*
*/ xsize(6.5) ysize(8.5)

graph export area_6.pdf, replace

