function [measure,entryrate,aggemp,entryemp,noexit,noentry] = geneqm(A,w,gamma,alpha,ce,saveout,pass)
global Nz Nc beta xi M rho_z sigma_z mu_c sigma_c 

%% Notes
%{
- If ceswitch=1, override ce input and set to mean of operating cost. Else
use ce input

- If saveout=1, save mu and V to disk.

- pass is an iteraction counter so the program knows where to save things
%}

%% Grids
[lnz,T,Ti]=tauchen(rho_z,sigma_z,Nz);
z=exp(lnz)';
Mu=Ti*100;
%Mu_e=Ti;        %Can easily adapt this to use a different distribution for potential entrants
Mu_e=paretodist(xi,z);

[lnc,Tc,Tic]=tauchen(0,sigma_c,Nc);
lnc=lnc+mu_c;
cf=exp(lnc)';
cfmat=repmat(cf',Nz,1);


L=(A*z).^(1/(1-alpha))*(w/alpha)^(1/(alpha-1));
pi=A*z.*L.^alpha-w*L;


%% Incumbents

% fprintf('Value function iteration...\n')
% fprintf('\n')
Vprime=ones(Nz,1);


gap=100;
while gap>0.000000000001
    Vtilde=beta*T*Vprime;
    Vtaug=Vtilde-cfmat;
    
    exit=Vtaug<0;
    Vtaug=max(0,Vtaug); %Provides all possible future values. Vertical is by possible z realizations, horizontal is by possible cf realizations.
    
    V=pi+Vtaug*Tic;     %Second term is expectation over cf realizations
    
    gap=sum(abs(Vprime-V));
    Vprime=V;
    
end
failrates=sum(exit.*repmat(Tic',Nz,1),2);     %For every s, share of firms that will exit due to high fixed cost draw
exitshare=Mu'*failrates;        %Total exit rate as share of firms


%% Entrants

enter=beta*T*Vprime>=ce;
%Note this treatment of startups treats their first prod draw as a
%"signal"; they get another draw before producing. This makes sense in C&P
%world where they must make an investment decision before the production
%draw. Here it just means they choose to enter based entirely on their
%noisy signal.

%% Distribution

% fprintf('Distribution iteration...\n')
% fprintf('\n')
Mu0=Mu;
exiters=sum(failrates);
entrants=sum(enter);
gap=100;
iter=1;
if exiters>0 && entrants>0
    while gap>0.0000000000001
        Mutemp=Mu0+M*Mu_e.*enter-failrates.*Mu0;           %Measure of incumbents plus incoming entrants minues outgoing exiters
        
        Muprime=Mutemp'*T;                                     %Advance the post-entry/exit distribution forward
        Muprime=Muprime';
        
        
        gap=sum(abs(Muprime-Mu0));
        
        if mod(iter,2)==0
             %gap
        end
        
        %[Mu0 Muprime]
        Mu0=Muprime;
        sum(Muprime);
        iter=iter+1;
    end
else
    Muprime=Mu0;
end



%% Key moments

measure=sum(Muprime);                       %Total measure of firms, note does not equal 1 in general
entryrate=sum(M*Mu_e.*enter)/measure;       %Entrants as share of total measure (startup rate)
exitrate=sum(failrates.*Mu0)/measure;       %Exits as share of total measure, equal to startup rate in SS

aggemp=sum(Muprime.*L);

%Startup employment
Mu_eprime=(M*Mu_e'*T)';                     %Actual distribution of startups after entry/new draws
entryemp=sum(Mu_eprime.*L);                 %Aggregate employment among entrants
entryempshare=entryemp/aggemp;              %Startup share of employment

if exiters==0
    noexit=1;
else
    noexit=0;
end

if entrants==0
    noentry=1;
else
    noentry=0;
end


%% mu and V saving
if saveout==1
    if pass==1
        state=[Muprime,V];
        save('state.mat','state');
        
        params=[A,w,gamma,ce,aggemp,entryemp,entryrate];
        save('params.mat','params');
    else
        load('state.mat')
        state(:,:,pass)=[Muprime,V];
        save('state.mat','state');
        
        load('params.mat')
        params(2,:)=[A,w,gamma,ce,aggemp,entryemp,entryrate];
        save('params.mat','params');
    end
end

        
        

        
     