function [measure,entryrate,aggemp,entryemp,noexit,EV] = geneqm2(A,w,Me,gamma,alpha,ce,saveout,pass)
global Nz Nc beta xi M rho_z sigma_z mu_c sigma_c 

%% This version eliminates pre-entry quality signal

%% Notes
%{
- If ceswitch=1, override ce input and set to mean of operating cost. Else
use ce input

- If saveout=1, save mu and V to disk.

- pass is an iteraction counter so the program knows where to save things
%}

%% Grids
[lnz,T,Ti]=tauchen(rho_z,sigma_z,Nz);
z=exp(lnz)';
Mu=Ti*100;
%Mu_e=Ti;        %Can easily adapt this to use a different distribution for potential entrants
Mu_e=paretodist(xi,z);

[lnc,Tc,Tic]=tauchen(0,sigma_c,Nc);
lnc=lnc+mu_c;
cf=exp(lnc)';
cfmat=repmat(cf',Nz,1);


L=(alpha*A*z./w).^(1/(1-alpha));
pi=A*z.*L.^alpha-w*L;


%% Incumbents

% fprintf('Value function iteration...\n')
% fprintf('\n')
Vprime=ones(Nz,1);
%Vprime=[-2,-1,0,1,2]';

gap=100;
while gap>0.000000000001
    Vtilde=beta*T*Vprime;
    Vtaug=Vtilde-cfmat;
    
    exit=Vtaug<0;
    Vtaug=max(0,Vtaug); %Provides all possible future values. Vertical is by possible z realizations, horizontal is by possible cf realizations.
    
    V=pi+Vtaug*Tic;     %Second term is expectation over cf realizations
    
    gap=sum(abs(Vprime-V));
    Vprime=V;
    
end
failrates=sum(exit.*repmat(Tic',Nz,1),2);     %For every s, share of firms that will exit due to high fixed cost draw
exitshare=Mu'*failrates;        %Total exit rate as share of firms

EV=Ti'*V;%Unconditional expectation of firm value, must equal ce in equilibrium




%% Distribution

% fprintf('Distribution iteration...\n')
% fprintf('\n')
Mu0=Mu;
exiters=sum(failrates);

gap=100;
iter=1;
if exiters>0
    while gap>0.0000000000001
        Mutemp=Mu0+Me*Ti-failrates.*Mu0;           %Measure of incumbents plus incoming entrants minues outgoing exiters
        
        Muprime=Mutemp'*T;                                     %Advance the post-entry/exit distribution forward
        Muprime=Muprime';
        
        
        gap=sum(abs(Muprime-Mu0));
        
        if mod(iter,2)==0
             %gap
        end
        
        %[Mu0 Muprime]
        Mu0=Muprime;
        sum(Muprime);
        iter=iter+1;
    end
else
    Muprime=Mu0;
end



%% Key moments

measure=sum(Muprime);                       %Total measure of firms, note does not equal 1 in general
entryrate=Me/measure;       %Entrants as share of total measure (startup rate)
exitrate=sum(failrates.*Mu0)/measure;       %Exits as share of total measure, equal to startup rate in SS

aggemp=sum(Muprime.*L);

%Startup employment
Mu_eprime=Me*Ti;                     %Actual distribution of startups after entry/new draws
entryemp=sum(Mu_eprime.*L);                 %Aggregate employment among entrants
entryempshare=entryemp/aggemp;              %Startup share of employment

if exiters==0
    noexit=1;
else
    noexit=0;
end




%% mu and V saving
if saveout==1
    if pass==1
        state=[Muprime,V];
        save('state.mat','state');
        
        params=[A,w,Me,gamma,ce,aggemp,entryemp,entryrate];
        save('params.mat','params');
    else
        load('state.mat')
        state(:,:,pass)=[Muprime,V];
        save('state.mat','state');
        
        load('params.mat')
        params(2,:)=[A,w,Me,gamma,ce,aggemp,entryemp,entryrate];
        save('params.mat','params');
    end
end

        
        

        
     