

import delimited series.csv,clear
graph set eps fontface "Times"
graph set window fontface "Times"
graph set ps fontface "Times"

rename v1 t

*Model 1 - quality signal, default param
rename v2 m1_a
rename v3 m1_entryrate
rename v4 m1_measure
rename v5 m1_entryemp

* Model 2 - quality signal, more curvature alpha=.7
rename v6 m2_a
rename v7 m2_entryrate
rename v8 m2_measure
rename v9 m2_entryemp

* Model 3 - quality signal, low elasticity gamma=1
rename v10 m3_a
rename v11 m3_entryrate
rename v12 m3_measure
rename v13 m3_entryemp

* Model 4 - no quality signal
rename v14 m4_a
rename v15 m4_entryrate
rename v16 m4_measure
rename v17 m4_entryemp


forvalues i=1/4 {
	local scale="0.6(.2)2"
	if "`i'"=="1" {
		local title="Quality signals"
		local leg="legend(off)"
		local fig="b"
	}
	if "`i'"=="2" {
		local title="Quality signals, {&alpha}=0.7"
		local leg="legend(off)"
		local fig="c"
	}
	if "`i'"=="3" {
		local title="Quality signals, {&gamma}=1"
		local leg="legend(off)"
		local fig="d"
	}
	if "`i'"=="4" {
		local title="Baseline model"
		local leg=""
		local scale=""
		local fig="a"
	}


	twoway (line m`i'_a t,lwidth(thick) lcolor(blue) lpattern(solid) msymbol(i))/*
	*/ (line m`i'_entryrate t,lwidth(thick) lcolor(red) lpattern(longdash) msymbol(i)) /*
	*/ (line m`i'_measure t,lwidth(thick) lpattern(dash) lcolor(black) msymbol(i)) /*
	*/ (line m`i'_entryemp t,lwidth(thick) lpattern(dash_dot) lcolor(green) msymbol(i)),/*
	*/graphregion(color(white) margin(tiny) fcolor(white) ifcolor(white) icolor(white))/*
	*/xtitle("Time",size(4.5)) xlabel(0(2)20,angle(45) labsize(4.5))/*
	*/ylabel(`scale',angle(horizontal)  nogrid labsize(4.5)) ytitle("Relative to initial level",size(4.5))/*
	*/ legend(label(1 "Aggregate TFP") label(2 "Entry rate") label(3 "Number of firms") label(4 "Entry emp. share") region(lcolor(white)) position(1) ring(0) cols(1) size(4.5) symxsize(10) keygap(1) rowgap(1)) yline(1,lcolor(black) lwidth(thin))/*
	*/`leg' subtitle("`title'",size(4.5) justification(left) margin(b+1 t) bexpand) ysize(3.25) xsize(3.25)
	graph save g`i',replace
	
	label variable m`i'_a "Aggregate TFP"
	label variable m`i'_entryrate "Entry rate"
	label variable m`i'_measure "Number of firms"
	label variable m`i'_entryemp "Entry emp. share"
	label variable t "Time"
	
	*export excel t m`i'_a m`i'_entryrate m`i'_measure m`i'_entryemp using $chartpack\chartpack.xlsx,sheet("A5`fig'") firstrow(varlabels) sheetreplace

}

graph combine g4.gph g1.gph g2.gph g3.gph, iscale(0.5)/*
subtitle("Margins of employment growth in boom towns",justification(left) margin(b+1 t) bexpand size(large))
*/ graphregion(color(white) margin(tiny))/*
*/xsize(6.5) ysize(6.5)
graph export model.pdf,replace
