%header

%% Some housekeeping
maxmktgap=0.001;
%maxmktgap=99.99;   %For partial equilibrium, set to 99.99
theta=0.01;          %Updating rate for wage, apply to implied wage

%% Grids
[lnz,T,Ti]=tauchen(rho_z,sigma_z,Nz);
z=exp(lnz)';
Mu=Ti*100;
%Mu_e=Ti;        %Can easily adapt this to use a different distribution for potential entrants
Mu_e=paretodist(xi,z);

[lnc,Tc,Tic]=tauchen(0,sigma_c,Nc);
lnc=lnc+mu_c;
cf=exp(lnc)';
cfmat=repmat(cf',Nz,1);






%% Transition paths
N=100;                  %Periods
load('params.mat')

A0=params(1,1);
AN=params(2,1);
Apath=ones(1,N)*AN;
Apath(1)=A0;


plot(1:length(Apath),Apath)

w0=params(1,2);
wN=params(2,2);
wpath=ones(1,N)*w0;

wpath(1)=w0;
wpath(length(wpath))=wN;

gamma=params(1,3);
ce=params(1,4);

aggemp0=params(1,5);
aggempN=params(2,5);

entryemp0=params(1,6);
entryempN=params(2,6);

entryempshare0=entryemp0/aggemp0;
entryempshareN=entryempN/aggempN;

entryrate0=params(1,7);
entryrateN=params(2,7);
clear params

load('state.mat')
Mu0=state(:,1,1);
MuN=state(:,1,2);

V0=state(:,2,1);
VN=state(:,2,2);

clear state

%% Market clearing iteration begins

mktiter=1;
mktgap=100*ones(1,N-1);
while max(abs(mktgap))>maxmktgap
%while mktiter<100
    if mktiter>1000 & max(abs(mktgap))<0.01
        break
    end
    
    failrates=zeros(Nz,N-1);
    

    %% Iterate backwards
    Vprime=VN;
    for t=N-1:-1:1
        w=wpath(t);
        A=Apath(t);

        L=(alpha*A*z./w).^(1/(1-alpha));
        pi=A*z.*L.^alpha-w*L;

        Vtilde=beta*T*Vprime;
        Vtaug=Vtilde-cfmat;

        exit=Vtaug<0;
        Vtaug=max(0,Vtaug); %Provides all possible future values. Vertical is by possible z realizations, horizontal is by possible cf realizations.

        V=pi+Vtaug*Tic;     %Second term is expectation over cf realizations

        enter=beta*T*Vprime>=ce;

        Vprime=V;

        failrates(:,t)=sum(exit.*repmat(Tic',Nz,1),2);     %For every s, share of firms that will exit due to high fixed cost draw; maps multiplicatively to mu
        entermeasures(:,t)=M*Mu_e.*enter; %Note these are raw measures mappable to mu additively


    end


    %% Ok now iterate forward.
    %Wake up in period 0 and produce, then immediately learn the future path of
    %A. Make entry/exit decisions based on that new knowledge.

    aggemp=zeros(1,N-1);
    entryemp=zeros(1,N-1);
    entryempshare=zeros(1,N-1);
    entryrate=zeros(1,N-1);
    measure=zeros(1,N-1);

    Mu=Mu0;
    for t=1:N-1
        w=wpath(t);
        A=Apath(t);  

        Mutemp=Mu+entermeasures(:,t)-failrates(:,t).*Mu;           %Measure of incumbents plus incoming entrants minues outgoing exiters
        %This is the new measure between period t-1 and t, after period t-1 production but
        %before investment/exit decision in advance of period t

        Muprime=Mutemp'*T;                                     %Advance the post-entry/exit distribution forward
        Muprime=Muprime';

        %Build some period-t outcomes
        L=(A*z).^(1/(1-alpha))*(w/alpha)^(1/(alpha-1));

        %Agg employment for market clearing
        aggemp(t)=sum(Muprime.*L);
        entryrate(t)=sum(entermeasures(:,t))/sum(Muprime);
        
        if aggemp(t)>0
            mktgap(t)=log(aggemp(t))-log(w^gamma);
            impliedwage=aggemp(t)^(1/gamma);
            wpath(t)=theta*impliedwage+(1-theta)*w;
        else
            wpath(t)=0.99*w;
        end
            
        
        

        %Startup employment
        Mu_eprime=(M*Mu_e'*T)';                     %Actual distribution of startups after entry/new draws
        entryemp(t)=sum(Mu_eprime.*L);                 %Aggregate employment among entrants
        entryempshare(t)=entryemp/aggemp;              %Startup share of employment

        measure(t)=sum(Muprime);
        
        Mu=Muprime;

    end
    
    max(abs(mktgap))
    
    if mktiter==1
        outgap=mktgap;
        save('outgap.mat','outgap');
    else
        load('outgap.mat')
        outgap=[outgap;mktgap];
        save('outgap.mat','outgap');
    end
    csvwrite('outgap.csv',outgap);
    
    mktiter=mktiter+1;
    
end

aggemp=[aggemp0,aggemp,aggempN];
entryemp=[entryemp0,entryemp,entryempN];
entryempshare=[entryempshare0,entryempshare,entryempshareN];
entryrate=[entryrate0,entryrate,entryrateN];
tpath=1:length(aggemp);
wpath=[w0,wpath];
measure=[sum(Mu0),measure,sum(MuN)];

figure
plot(tpath,aggemp)
hold on
plot(tpath,entryemp)
hold off


figure
plot(tpath,wpath)

figure
plot(tpath,entryempshare)

hold on
figure
yyaxis left
plot(tpath,[A0,Apath])
ylim([0.7 1.3])
xlim([0 100])
yyaxis right
plot(tpath,entryrate)
hold off

hold on
figure
plot(tpath,[A0,Apath/A0])
hold on
plot(tpath,entryrate/entryrate(1))
hold on
plot(tpath,measure/sum(Mu0))

hold off

figure
plot(tpath,[A0,Apath/A0],'b','LineWidth',3)
hold on
plot(tpath,entryrate/entryrate(1),'--r','LineWidth',3)
hold on
plot(tpath,measure/sum(Mu0),':k','LineWidth',3)
hold on
plot(tpath,entryempshare/entryempshare0,'-.g','LineWidth',2)
hold on
%plot(zvec,c,'--k')
%hold on
%plot(zvec,zbarvec,':k')
%set(gca,'XTick',tpath)
%set(gca,'XtickLabel',['z*(low tax) ';'z*(med tax) ';'z*(high tax)'])
title('Response to positive aggregate shock')
ylabel('Relative to initial level','FontSize',15)
xlabel('time','FontSize',15)
xlim([0 20])
lgd=legend('Aggregate TFP','Entry rate','Number of firms','Emp. share','Location','northeast')
lgd.FontSize=12;
saveas(gcf,'transition_cp.png')
hold off

temp=[[A0,Apath(1:19)/A0];entryrate(1:20)/entryrate(1);measure(1:20)/sum(Mu0);entryempshare(1:20)/entryempshare0]';
load('series.mat')
series=[series,temp];
save('series.mat','series');
csvwrite('series.csv',series);